/**
 * Copyright 2019 Google LLC. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { GitHub } from './github';
export declare enum ReleaseType {
    Node = "node",
    PHPYoshi = "php-yoshi",
    JavaAuthYoshi = "java-auth-yoshi"
}
export interface ReleasePROptions {
    bumpMinorPreMajor?: boolean;
    label: string;
    token?: string;
    repoUrl: string;
    packageName: string;
    releaseAs?: string;
    releaseType: ReleaseType;
    apiUrl: string;
    proxyKey?: string;
    snapshot?: boolean;
}
export interface ReleaseCandidate {
    version: string;
    previousTag?: string;
}
export declare class ReleasePR {
    apiUrl: string;
    labels: string[];
    gh: GitHub;
    bumpMinorPreMajor?: boolean;
    repoUrl: string;
    token: string | undefined;
    packageName: string;
    releaseAs?: string;
    releaseType: ReleaseType;
    proxyKey?: string;
    snapshot?: boolean;
    constructor(options: ReleasePROptions);
    run(): Promise<void>;
    private nodeRelease;
    private phpYoshiRelease;
    private releaseAllPHPLibraries;
    private javaAuthYoshiRelease;
    private closeStaleReleasePRs;
    private coerceReleaseCandidate;
    private commits;
    private gitHubInstance;
    private openPR;
}
